# Local Development

## Background
This docker-compose uses the main Dockerfile to create a `localdev-web-1` container and creates a mysql container called `localdev-database-1` and an edge container called `localdev-edge-1`.

## Prerequisites
1. Download docker without Docker Desktop, at least version 27.0.1.

For mac development:
1. Download colima using homebrew.
2. Start colima and edit virtual machine sizes using `colima start --edit`. Increase the number of CPUs to 16 and the memory to 16.

For windows development:
1. Install Docker on WSL2. You can find instructions [here](https://docs.docker.com/engine/install/ubuntu/).

For both OS:

Add the following env vars to your .bashrc or .zshrc or an .env file. See the instructions [here](../docs/metadata_webservice.md) for instructions on creating the OPENID_CLIENT_ID and OPENID_CLIENT_SECRET. The rest of the values can be set to strings of your choice. If you set the values in your .bashrc or .zshrc, run the source command to pick up the new values (ex `source ~/.bashrc`).
```
export OPENID_CLIENT_ID=""
export OPENID_CLIENT_SECRET=""
export SECRET_KEY=""
export SECRET_SALT=""
export MYSQL_ROOT_PASSWORD=""
```

## Use
To simply build and run all the containers, make sure you are in the /localdev directory and run the following command. This includes a reload command for the web container. It will restart the web container when changes are made locally.
```
docker-compose up
```
or `docker compose up` if you're not using the docker-compose plugin.

If you're not developing locally, use the following command to run the containers in the background. Reload will not work this way.
```
docker-compose up -d 
```
or `docker compose up -d` if not using the docker-compose plugin.

## Helpful Docker Commands
`docker ps` shows the running containers. 

`docker ps -a` shows all the containers, even ones that have exited. This is helpful to see logs for containers that have unexpectedly exited.

`docker exec -it {CONTAINER ID} /bin/bash` execs into the container. This can be helpful for exploring the mysql db. After you exec into the mysql container, run `mysql -u root -p` in the container. Input the password you set to MYSQL_ROOT_PASSWORD. Now you can use SQL to explore the db.

## Helpful Tips
Sometimes the mysql container exits immediately with code 139 due to insufficient memory. You can clean up your docker resources using the `cleanup-docker.sh` script in this folder. Restarting colima can also resolve this issue.
