import pytest


@pytest.fixture()
def valid_token():
    return {
        "access_token": "test_access_token",
        "token_type": "Bearer",
        "expires_in": 7200,
        "refresh_token": "test_refresh_toekn",
        "scope": "openid email profile",
        "created_at": 1733244369,
        "id_token": "test_id_token",
        "expires_at": 1733251569,
        "userinfo": {
            "iss": "http://test_url",
            "sub": "1234",
            "aud": "test_aud",
            "exp": 1733244489,
            "iat": 1733244369,
            "nonce": "test_nonce",
            "auth_time": 1733244368,
            "sub_legacy": "test_sub_legacy",
            "name": "test_user",
            "nickname": "test_user_nickname",
            "preferred_username": "test_preferred_username",
            "email": "test_email",
            "email_verified": True,
            "profile": "http://test_url/user",
            "picture": "http://picture_url",
            "groups_direct": ["group1", "group2"],
        },
    }


@pytest.fixture()
def valid_userinfo():
    return {
        "sub": "1234",
        "sub_legacy": "test_sub_legacy",
        "name": "test_user",
        "nickname": "test_user_nickname",
        "preferred_username": "test_preferred_username",
        "email": "test_email",
        "email_verified": True,
        "profile": "http://test_url/user",
        "picture": "http://picture_url",
        "groups": ["group1", "group2"],
    }


@pytest.fixture()
def valid_gitlab_user():
    return {
        "id": 1234,
        "email": "test_email",
        "name": "test_user",
        "username": "test_user_nickname",
        "avatar_url": "http://picture_url",
    }


@pytest.fixture()
def valid_reading_metadata():
    return {
        "created_by": "test_user",
        "starttime": "2024-11-07T12:12:12Z",
        "endtime": "2024-11-07T20:20:20Z",
        "network": "NT",
        "station": "BOU",
        "category": "reading",
        "data_valid": True,
        "metadata": {
            "azimuth": 199.1383,
            "metadata": {
                "time": "2020-01-03T17:12:47Z",
                "station": "BOU",
                "observer": "Test Observer",
                "reviewed": True,
                "reviewer": "Test Reviewer",
                "mark_name": "AZ",
                "pier_name": "MainPCDCP",
                "theodolite": "108449",
                "electronics": "0110",
                "mark_azimuth": 199.1383,
                "pier_correction": -22,
            },
            "absolutes": [
                {
                    "shift": 0,
                    "valid": True,
                    "element": "D",
                    "endtime": "2020-01-03T17:16:21.000000Z",
                    "absolute": 8.3851056,
                    "baseline": 8.58571,
                    "starttime": "2020-01-03T17:12:47.000000Z",
                },
                {
                    "shift": 0,
                    "valid": True,
                    "element": "H",
                    "endtime": "2020-01-03T17:24:40.000000Z",
                    "absolute": 20728.0650365,
                    "baseline": -71.7177135,
                    "starttime": "2020-01-03T17:20:48.000000Z",
                },
                {
                    "shift": 0,
                    "valid": True,
                    "element": "Z",
                    "endtime": "2020-01-03T17:24:40.000000Z",
                    "absolute": 47450.1529433,
                    "baseline": 578.2041933,
                    "starttime": "2020-01-03T17:20:48.000000Z",
                },
            ],
            "hemisphere": 1,
            "diagnostics": None,
            "scale_value": None,
            "measurements": [
                {
                    "e": None,
                    "f": None,
                    "h": None,
                    "z": None,
                    "angle": 191.56666666666666,
                    "measurement_type": "FirstMarkDown",
                },
                {
                    "e": None,
                    "f": None,
                    "h": None,
                    "z": None,
                    "angle": 11.566666666666666,
                    "measurement_type": "FirstMarkUp",
                },
                {
                    "e": None,
                    "f": None,
                    "h": None,
                    "z": None,
                    "angle": 191.56666666666666,
                    "measurement_type": "SecondMarkDown",
                },
                {
                    "e": None,
                    "f": None,
                    "h": None,
                    "z": None,
                    "angle": 11.566666666666666,
                    "measurement_type": "SecondMarkUp",
                },
                {
                    "e": -72.242,
                    "f": 51801.81,
                    "h": 20800.329,
                    "z": 46871.49,
                    "angle": 270.71666666666664,
                    "measurement_type": "WestDown",
                    "time": "2024-11-07T12:12:12Z",
                },
                {
                    "e": -72.636,
                    "f": 51801.92,
                    "h": 20800.259,
                    "z": 46871.641,
                    "angle": 90.66666666666667,
                    "measurement_type": "EastDown",
                    "time": "2024-11-07T12:13:14Z",
                },
                {
                    "e": -72.657,
                    "f": 51801.82,
                    "h": 20800.259,
                    "z": 46871.521,
                    "angle": 90.93333333333334,
                    "measurement_type": "WestUp",
                    "time": "2024-11-07T13:13:11Z",
                },
                {
                    "e": -72.758,
                    "f": 51801.92,
                    "h": 20800.086,
                    "z": 46871.707,
                    "angle": 270.96666666666664,
                    "measurement_type": "EastUp",
                    "time": "2024-11-07T13:15:12Z",
                },
                {
                    "e": -72.898,
                    "f": 51801.89,
                    "h": 20799.796,
                    "z": 46871.802,
                    "angle": 246.38333333333333,
                    "measurement_type": "SouthDown",
                    "time": "2024-11-07T15:12:12Z",
                },
                {
                    "e": -72.8,
                    "f": 51802.01,
                    "h": 20799.852,
                    "z": 46871.919,
                    "angle": 66.38333333333334,
                    "measurement_type": "NorthUp",
                    "time": "2024-11-07T18:12:12Z",
                },
                {
                    "e": -72.775,
                    "f": 51802.01,
                    "h": 20799.668,
                    "z": 46871.997,
                    "angle": 113.58333333333333,
                    "measurement_type": "SouthUp",
                    "time": "2024-11-07T19:12:19Z",
                },
                {
                    "e": -72.813,
                    "f": 51802.14,
                    "h": 20799.815,
                    "z": 46872.077,
                    "angle": 293.5833333333333,
                    "measurement_type": "NorthDown",
                    "time": "2024-11-07T20:20:20Z",
                },
                {"measurement_type": "Meridian", "angle": 21},
            ],
            "pier_correction": -22,
        },
    }
